@@ -1,10 +1,8 @@
 import pprint
 from functools import wraps
-from io import BytesIO, StringIO
+from io import StringIO
 from typing import Any, Dict, List, Pattern, Tuple, Union
 
-import urllib3
-
 try:
     import ujson as json
 except ImportError:
@@ -73,14 +71,6 @@ def parse_callback_data(callback_data: str, name: str):
     return (None, )
 
 
-def build_force_reply_data(*args):
-    return args
-
-
-def parse_force_reply_data(force_reply_data) -> Tuple:
-    return force_reply_data[0], tuple(force_reply_data[1:])
-
-
 def compose_message_entities(text_entities: Union[List, Tuple],
                              sep: str = " "):
     with StringIO() as buffer_:
@@ -107,17 +97,3 @@ def compose_message_entities(text_entities: Union[List, Tuple],
                 entities += inner_entities
                 entity.length = len(inner_text)
         return buffer_.getvalue(), tuple(entities)
-
-
-def get_file_bytes(file_url: str, chunk_size: int = 128) -> bytes:
-    http = urllib3.PoolManager(num_pools=1)
-    response = http.request("GET", file_url, preload_content=False)
-    try:
-        if response.status == 200:
-            with BytesIO() as buffer:
-                for chunk in response.stream(chunk_size):
-                    buffer.write(chunk)
-                return buffer.getvalue()
-        raise Exception("HTTP Error: {0}".format(response.status))
-    finally:
-        response.release_conn()
